
***Do File for "Bureaucratic Control and Strategic Compliance: How Do Subnational Governments Implement Central Guidelines in China?"***


*************************************************************************
                 *Tables and Figures in the Manuscript*
*************************************************************************


****Table 2: Pooled Event History Analysis****
egen s2_rule=std(rule_2)

logit d institution conference central_salience s_wordnum monitor age_1 age_2 sameplace_1 sameplace_2 lrevenue s2_rule i.duration i.region, vce(cluster policy_id)
outreg2 using 200707_EHA_result, word replace dec(3) stats(coef pval)
estat ic

logit d institution conference central_salience s_wordnum monitor age_1 age_2 sameplace_1 sameplace_2 lrevenue s2_rule conference##c.s2_rule i.duration i.region, vce(cluster policy_id)
outreg2 using 200707_EHA_result, word dec(3) stats(coef pval)
estat ic

logit d institution conference central_salience s_wordnum monitor age_1 age_2 sameplace_1 sameplace_2 c.s2_rule##c.lrevenue i.duration i.region, vce(cluster policy_id)
outreg2 using 200707_EHA_result, word dec(3) stats(coef pval)
estat ic

logit d institution conference central_salience s_wordnum monitor age_1 age_2 sameplace_1 sameplace_2 s2_rule lrevenue monitor##c.s2_rule i.duration i.region, vce(cluster policy_id)
outreg2 using 200707_EHA_result, word dec(3) stats(coef pval)
estat ic


****Table 3: Heckman Selection Model****
heckman central_similarity s2_rule conference  monitor lrevenue s_wordnum central_salience age_2 sameplace_1 sameplace_2 i.duration i.region, ///
select(d=institution age_1 s2_rule conference  monitor lrevenue s_wordnum central_salience age_2 sameplace_1 sameplace_2 i.duration i.region) vce(cluster policy_id)
outreg2 using 200707_heckman,word dec(3) stats(coef pval) replace

heckman central_similarity_2 s2_rule conference  monitor lrevenue s_wordnum central_salience age_2 sameplace_1 sameplace_2 i.duration i.region, ///
select(d=institution age_1 s2_rule conference  monitor lrevenue s_wordnum central_salience age_2 sameplace_1 sameplace_2 i.duration i.region) vce(cluster policy_id)
outreg2 using 200707_heckman,word dec(3) stats(coef pval)


****Figure 1: Kaplan-Meier Survival Estimate****
stset duration, id(policy_state) failure(d)
sts graph


****Figure 2: Marginal Effect of Bureaucratic Control on Provincial Governments’ Compliance as Provincial Revenue Changes****
logit d institution conference central_salience s_wordnum monitor age_1 age_2 sameplace_1 sameplace_2 c.s2_rule##c.lrevenue i.duration i.region, vce(cluster policy_id)

margins, dydx(s2_rule) at(lrevenue=(-3.5(0.1)0.1)) level(90)
matrix A = r(at) 
matrix list A
matrix B = r(table)'
matrix D = A[1..37, "lrevenue_2"]
matrix C = B, D
tempname tempr
svmat C, name(`tempr')

twoway (hist lrevenue if d!=. & lrevenue>=-3.5 & lrevenue<=0.1, yaxis(2) xlabel(-3.5(0.5)0) yscale(axis(2) alt) color(gs14) ytitle("Density of Provincial Revenue", axis(2) size(medium)) xtitle("Per Capita Provincial Revenue (Log Form)", size(medium))) ///
(function y=0, ra(-3.5 0.1)) ///
(line `tempr'1 `tempr'10, yaxis(1) yscale(axis(1) alt) lcolor(navy) ytitle("Effects of Bureaucratic Control on Provincial Compliance", size(medium))) ///
(rline `tempr'5 `tempr'6 `tempr'10, lpattern(shortdash) yaxis(1) lcolor(navy)) ///
, legend(off) 
drop `tempr'*


****Figure 3: Moderating Effect of National Conference on Provincial Governments' Compliance with Central Guidelines****
logit d institution conference##c.s2_rule central_salience s_wordnum monitor age_1 age_2 sameplace_1 sameplace_2 lrevenue i.duration i.region, vce(cluster policy_id)

margins conference, at(s2_rule=(-1.03(0.025)1.5)) level(90)
matrix C = r(table)'
matrix A = r(at)
matrix A = A[1..102,"s2_rule"]

forval i=1/102 {

matrix b=C["`i'._at#0.conference","b".."ul"]
if `i'==1 {
matrix F=b
}
else if `i'!=1 {
matrix F=(F\b)
}
}

forval i=1/102 {

matrix b=C["`i'._at#1.conference","b".."ul"]
if `i'==1 {
matrix G=b
}
else if `i'!=1 {
matrix G=(G\b)
}
}




matrix ca1=A,F
matrix ca2=A,G
tempname catt1
svmat ca1, name(`catt1')
tempname catt2
svmat ca2, name(`catt2')

twoway (hist s2_rule if d!=. & s2_rule>=-1.03 & s2_rule<=1.5, yaxis(2) xlabel(-1.0(0.5)1.5) yscale(axis(2) alt) color(gs14) ytitle("Density of Extents of Control",axis(2) size(medium)) xtitle("Extents of Control (standardized)",size(medium))) ///
(line `catt1'2 `catt1'1,yaxis(1) yscale(axis(1) alt) ylabel(0.1(0.1)0.5) lcolor(navy) ytitle("Probability of Releasing Implementation Document",size(medium))) ///
(rline `catt1'7 `catt1'6 `catt1'1, lpattern(shortdash) yaxis(1) lcolor(navy)) ///
(line `catt2'2 `catt2'1,yaxis(1) lcolor(maroon) lpattern(dash)) ///
(rline `catt2'7 `catt2'6 `catt2'1, lpattern(shortdash) yaxis(1) lcolor(maroon)) ///
, legend(order(2 "No Conference" 4 "Conference"))

drop `catt1'*  `catt2'*




*************************************************************************
               *Tables and Figures in the Printed Appendix*
*************************************************************************


****Table A1: Variable Descriptions and Summary Statistics****
sum rule_2 rule revenue_person conference monitor institution central_salience wordnum_total age_1 age_2 sameplace_1 sameplace_2   


****Table A2: Summary Statistics of Different Policy Fields of Central Guidelines****
preserve
collapse (mean) conference monitor central_salience institution wordnum_total rule_2 type2, by(policy_id)
sort type2
by type2: sum institution wordnum_total central_salience conference monitor rule_2 
restore


****Table A3: Summary Statistics of Provincial Governments in Different Regions of China****
sort region
by region: sum central_similarity

preserve
collapse (mean) revenue_person age_1 age_2 sameplace_1 sameplace_2, by(region state year)
sort region
by region: sum revenue_person age_1 age_2 sameplace_1 sameplace_2

preserve 
collapse (max) d, by(region state policy_id)
sort region
by region: sum d


****Figure A1: Pooled Event History Analysis****
*panel A*
logit d institution conference central_salience s_wordnum monitor age_1 age_2 sameplace_1 sameplace_2 c.s_rule##c.lrevenue i.duration i.region, vce(cluster policy_id)
margins, dydx(s_rule) at(lrevenue=(-3.5(0.1)0.1)) level(90)
matrix A = r(at) 
matrix list A
matrix B = r(table)'
matrix D = A[1..37, "lrevenue_2"]
matrix C = B, D
tempname tempr
svmat C, name(`tempr')
twoway (hist lrevenue if d!=. & lrevenue>=-3.5 & lrevenue<=0.1, yaxis(2) xlabel(-3.5(0.5)0) yscale(axis(2) alt) color(gs14) ytitle("Density of Provincial Revenue", axis(2) size(medium)) xtitle("Per Capita Provincial Revenue (Log Form)", size(medium))) ///
(function y=0, ra(-3.5 0.1)) ///
(line `tempr'1 `tempr'10, yaxis(1) yscale(axis(1) alt) lcolor(navy) ytitle("Effects of Bureaucratic Control", size(medium))) ///
(rline `tempr'5 `tempr'6 `tempr'10, lpattern(shortdash) yaxis(1) lcolor(navy)) ///
, legend(off) 
drop `tempr'*

*panel B*
logit d institution conference##c.s_rule central_salience s_wordnum monitor age_1 age_2 sameplace_1 sameplace_2 lrevenue i.duration i.region, vce(cluster policy_id)
margins conference, at(s_rule=(-1.04(0.1)1.66)) level(90)
matrix C = r(table)'
matrix A = r(at)
matrix A = A[1..28,"s_rule"]
forval i=1/28 {

matrix b=C["`i'._at#0.conference","b".."ul"]
if `i'==1 {
matrix F=b
}
else if `i'!=1 {
matrix F=(F\b)
}
}

forval i=1/28 {

matrix b=C["`i'._at#1.conference","b".."ul"]
if `i'==1 {
matrix G=b
}
else if `i'!=1 {
matrix G=(G\b)
}
}




matrix ca1=A,F
matrix ca2=A,G
tempname catt1
svmat ca1, name(`catt1')
tempname catt2
svmat ca2, name(`catt2')
twoway (hist s_rule if d!=. & s_rule>=-1.04 & s_rule<=1.66, yaxis(2) xlabel(-1.0(0.5)1.5) yscale(axis(2) alt) color(gs14) xtitle("Extents of Control (Expanded, Standardized)",size(medium))) ///
(line `catt1'2 `catt1'1,yaxis(1) yscale(axis(1) alt) ylabel(0(0.1)0.5) lcolor(navy) ytitle("Probability of Compliance",size(medium))) ///
(rline `catt1'7 `catt1'6 `catt1'1, lpattern(shortdash) yaxis(1) lcolor(navy)) ///
(line `catt2'2 `catt2'1,yaxis(1) lcolor(maroon) lpattern(dash)) ///
(rline `catt2'7 `catt2'6 `catt2'1, lpattern(shortdash) yaxis(1) lcolor(maroon)) ///
, legend(order(2 "No Conference" 4 "Conference"))
drop `catt1'*  `catt2'*

*panel C*
logit d institution conference central_salience s_wordnum monitor age_1 age_2 sameplace_1 sameplace_2 c.s_humanrule##c.lrevenue i.duration i.region, vce(cluster policy_id)
margins, dydx(s_humanrule) at(lrevenue=(-3.5(0.1)0.1)) level(90)
matrix A = r(at) 
matrix list A
matrix B = r(table)'
matrix D = A[1..37, "lrevenue_2"]
matrix C = B, D
tempname tempr
svmat C, name(`tempr')
twoway (hist lrevenue if d!=. & lrevenue>=-3.5 & lrevenue<=0.1, yaxis(2) xlabel(-3.5(0.5)0) yscale(axis(2) alt) color(gs14)  xtitle("Per Capita Provincial Revenue (Log Form)", size(medium))) ///
(function y=0, ra(-3.5 0.1)) ///
(line `tempr'1 `tempr'10, yaxis(1) yscale(axis(1) alt) lcolor(navy) ytitle("Effects of Bureaucratic Control", size(medium))) ///
(rline `tempr'5 `tempr'6 `tempr'10, lpattern(shortdash) yaxis(1) lcolor(navy)) ///
, legend(off) 
drop `tempr'*

*panel D*
logit d institution conference##c.s_humanrule central_salience s_wordnum monitor age_1 age_2 sameplace_1 sameplace_2 lrevenue i.duration i.region, vce(cluster policy_id)
margins conference, at(s_humanrule=(-1.27(0.372)2.45)) level(90)
matrix C = r(table)'
matrix A = r(at)
matrix A = A[1..11,"s_humanrule"]
forval i=1/11 {

matrix b=C["`i'._at#0.conference","b".."ul"]
if `i'==1 {
matrix F=b
}
else if `i'!=1 {
matrix F=(F\b)
}
}

forval i=1/11 {

matrix b=C["`i'._at#1.conference","b".."ul"]
if `i'==1 {
matrix G=b
}
else if `i'!=1 {
matrix G=(G\b)
}
}




matrix ca1=A,F
matrix ca2=A,G
tempname catt1
svmat ca1, name(`catt1')
tempname catt2
svmat ca2, name(`catt2')
twoway (hist s_humanrule if d!=. & s_humanrule>=-1.27 & s_humanrule<=2.45, yaxis(2) xlabel(-1.3(0.5)2.2) yscale(axis(2) alt) color(gs14) xtitle("Extents of Control (Human-coded, Standardized)",size(medium))) ///
(line `catt1'2 `catt1'1,yaxis(1) yscale(axis(1) alt) ylabel(0.1(0.1)0.5) lcolor(navy) ytitle("Probability of Compliance",size(medium))) ///
(rline `catt1'7 `catt1'6 `catt1'1, lpattern(shortdash) yaxis(1) lcolor(navy)) ///
(line `catt2'2 `catt2'1,yaxis(1) lcolor(maroon) lpattern(dash)) ///
(rline `catt2'7 `catt2'6 `catt2'1, lpattern(shortdash) yaxis(1) lcolor(maroon)) ///
, legend(order(2 "No Conference" 4 "Conference"))
drop `catt1'*  `catt2'*

*panel E*
logit d institution conference central_salience s_wordnum monitor age_1 age_2 sameplace_1 sameplace_2 c.s2_rule##c.lrevenue i.duration i.region i.type2, vce(cluster policy_id)
margins, dydx(s2_rule) at(lrevenue=(-3.5(0.1)0.1)) level(90)
matrix A = r(at) 
matrix list A
matrix B = r(table)'
matrix D = A[1..37, "lrevenue_2"]
matrix C = B, D
tempname tempr
svmat C, name(`tempr')
twoway (hist lrevenue if d!=. & lrevenue>=-3.5 & lrevenue<=0.1, yaxis(2) xlabel(-3.5(0.5)0) yscale(axis(2) alt) color(gs14)  xtitle("Per Capita Provincial Revenue (Log Form)", size(medium))) ///
(function y=0, ra(-3.5 0.1)) ///
(line `tempr'1 `tempr'10, yaxis(1) yscale(axis(1) alt) lcolor(navy) ytitle("Effects of Bureaucratic Control", size(medium))) ///
(rline `tempr'5 `tempr'6 `tempr'10, lpattern(shortdash) yaxis(1) lcolor(navy)) ///
, legend(off) 
drop `tempr'*

*panel F*
sum s2_rule, detail
logit d institution conference##c.s2_rule central_salience s_wordnum monitor age_1 age_2 sameplace_1 sameplace_2 lrevenue i.duration i.region i.type2, vce(cluster policy_id)
margins conference, at(s2_rule=(-1.03(0.025)1.5)) level(90)
matrix C = r(table)'
matrix A = r(at)
matrix A = A[1..102,"s2_rule"]
forval i=1/102 {

matrix b=C["`i'._at#0.conference","b".."ul"]
if `i'==1 {
matrix F=b
}
else if `i'!=1 {
matrix F=(F\b)
}
}

forval i=1/102 {

matrix b=C["`i'._at#1.conference","b".."ul"]
if `i'==1 {
matrix G=b
}
else if `i'!=1 {
matrix G=(G\b)
}
}




matrix ca1=A,F
matrix ca2=A,G
tempname catt1
svmat ca1, name(`catt1')
tempname catt2
svmat ca2, name(`catt2')
twoway (hist s2_rule if d!=. & s2_rule>=-1.03 & s2_rule<=1.5, yaxis(2) xlabel(-1.0(0.5)1.5) yscale(axis(2) alt) color(gs14) ytitle("Density of Degree of Control",axis(2) size(medium)) xtitle("Extents of Control (standardized)",size(medium))) ///
(line `catt1'2 `catt1'1,yaxis(1) yscale(axis(1) alt) ylabel(0(0.1)0.5) lcolor(navy) ytitle("Probability of Releasing Implementation Document",size(medium))) ///
(rline `catt1'7 `catt1'6 `catt1'1, lpattern(shortdash) yaxis(1) lcolor(navy)) ///
(line `catt2'2 `catt2'1,yaxis(1) lcolor(maroon) lpattern(dash)) ///
(rline `catt2'7 `catt2'6 `catt2'1, lpattern(shortdash) yaxis(1) lcolor(maroon)) ///
, legend(order(2 "No Conference" 4 "Conference"))
drop `catt1'*  `catt2'*

graph combine panela.gph panelb.gph panelc.gph paneld.gph panele.gph panelf.gph, row(3)



*************************************************************************
          *Tables and Figures in Online Supporting Information*
*************************************************************************


****Table B1: Pooled Event History Analysis after Including Policy Field Fixed Effects****
logit d institution conference central_salience s_wordnum monitor age_1 age_2 sameplace_1 sameplace_2 lrevenue s2_rule i.duration i.region i.type2, vce(cluster policy_id)
outreg2 using 200707_EHA_result, word replace dec(3) stats(coef pval)
estat ic

logit d institution conference central_salience s_wordnum monitor age_1 age_2 sameplace_1 sameplace_2 lrevenue s2_rule conference##c.s2_rule i.duration i.region i.type2, vce(cluster policy_id)
outreg2 using 200707_EHA_result, word dec(3) stats(coef pval)
estat ic

logit d institution conference central_salience s_wordnum monitor age_1 age_2 sameplace_1 sameplace_2 c.s2_rule##c.lrevenue i.duration i.region i.type2, vce(cluster policy_id)
outreg2 using 200707_EHA_result, word dec(3) stats(coef pval)
estat ic

logit d institution conference central_salience s_wordnum monitor age_1 age_2 sameplace_1 sameplace_2 s2_rule lrevenue monitor##c.s2_rule i.duration i.region i.type2, vce(cluster policy_id)
outreg2 using 200707_EHA_result, word dec(3) stats(coef pval)
estat ic


****Table B2: Heckman Selection Model after Including Policy Field Fixed Effects****
heckman central_similarity s2_rule conference  monitor lrevenue s_wordnum central_salience age_2 sameplace_1 sameplace_2 i.duration i.region i.type2, ///
select(d=institution age_1 s2_rule conference  monitor lrevenue s_wordnum central_salience age_2 sameplace_1 sameplace_2 i.duration i.region i.type2) vce(cluster policy_id)
outreg2 using 200707_heckman,word dec(3) stats(coef pval) replace

heckman central_similarity_2 s2_rule conference  monitor lrevenue s_wordnum central_salience age_2 sameplace_1 sameplace_2 i.duration i.region i.type2, ///
select(d=institution age_1 s2_rule conference  monitor lrevenue s_wordnum central_salience age_2 sameplace_1 sameplace_2 i.duration i.region i.type2) vce(cluster policy_id)
outreg2 using 200707_heckman,word dec(3) stats(coef pval)


****Table B5: Rerunning Pooled Event History Analysis on Two Subsamples****
logit d s2_rule lrevenue conference monitor institution central_salience s_wordnum  age_1 age_2 sameplace_1 sameplace_2  i.duration i.region if rule_2<0.0054, vce(cluster policy_id)
outreg2 using 200707_EHA_result, word replace dec(3) stats(coef pval)
estat ic

logit d s2_rule lrevenue conference monitor institution central_salience s_wordnum  age_1 age_2 sameplace_1 sameplace_2  i.duration i.region if rule_2>=0.0054, vce(cluster policy_id)
outreg2 using 200707_EHA_result, word dec(3) stats(coef pval)
estat ic

logit d s2_rule lrevenue conference monitor institution central_salience s_wordnum  age_1 age_2 sameplace_1 sameplace_2  i.duration i.region, vce(cluster policy_id)
outreg2 using 200707_EHA_result, word dec(3) stats(coef pval)
estat ic

